@@ -3,7 +3,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2006-2011 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2006-2012 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -34,7 +34,7 @@ class StoqCommandHandler:
 
     def _read_config(self, options, create=False, register_station=True,
                      check_schema=True, load_plugins=True):
-        from stoq.lib.configparser import StoqConfig
+        from stoqlib.lib.configparser import StoqConfig
         from stoq.lib.startup import setup
         config = StoqConfig()
         if options.load_config and options.filename:
@@ -68,26 +68,49 @@ class StoqCommandHandler:
     def run_command(self, options, cmd, args):
         func = getattr(self, 'cmd_' + cmd, None)
         if func is None:
-            print "%s: Invalid command: `%s' type `%s help' for usage." % (
-                self.prog_name, cmd, self.prog_name)
-            return 1
+            self._read_config(options, load_plugins=False,
+                              register_station=False)
+            from stoqlib.lib.pluginmanager import get_plugin_manager
+            manager = get_plugin_manager()
+            if cmd in manager.installed_plugins_names:
+                if not len(args):
+                    raise SystemExit(
+                        "%s: %s requires at least 2 argument(s)" % (
+                        self.prog_name, cmd))
+                plugin = manager.get_plugin(cmd)
+                return plugin.handle_dbadmin_command(args[0], options, args[1:])
+            else:
+                print "%s: Invalid command: `%s' type `%s help' for usage." % (
+                    self.prog_name, cmd, self.prog_name)
+                return 1
 
         nargs = func.func_code.co_argcount - 2
         if len(args) < nargs:
             raise SystemExit(
                 "%s: %s requires at least %d argument(s)" % (
                 self.prog_name, cmd, nargs))
-
+        self.args = args
         return func(options, *args)
 
     def cmd_help(self, options):
         cmds = [attr[4:] for attr in dir(self) if attr.startswith('cmd_')]
         cmds.sort()
         cmds.remove('help')
+
         print 'Available commands:'
         for name in cmds:
             print '  ', name
-        print
+
+        self._read_config(options, load_plugins=False,
+                          register_station=False)
+
+        from stoqlib.lib.pluginmanager import get_plugin_manager
+        manager = get_plugin_manager()
+        for plugin_name in manager.installed_plugins_names:
+            plugin = manager.get_plugin(plugin_name)
+            for command in plugin.get_dbadmin_commands():
+                print '   %s %s' % (plugin_name, command)
+
         return 0
 
     def cmd_init(self, options):
@@ -356,6 +379,33 @@ class StoqCommandHandler:
                          help="Filename to import",
                          dest="filename")
 
+    def cmd_console(self, options):
+        from stoqlib.lib.console import Console
+        self._read_config(options, register_station=False)
+        console = Console()
+        console.populate_namespace(options.bare)
+        if options.script:
+            console.execute(options.script)
+        else:
+            console.interact()
+
+        if options.commit:
+            console.trans.commit()
+
+    def opt_console(self, parser, group):
+        group.add_option('-b', '--bare',
+                         action="store_true",
+                         dest="bare")
+        group.add_option('-c', '--command',
+                         action="store_true",
+                         dest="command")
+        group.add_option('', '--commit',
+                         action="store_true",
+                         dest="commit")
+        group.add_option('-s', '--script',
+                         action="store",
+                         dest="script")
+
 
 def main(args):
     pname = args[0]
