@@ -39,13 +39,14 @@ from stoqlib.database.orm import ORMObjectQueryExecuter
 from stoqlib.lib.interfaces import IAppInfo
 from stoqlib.lib.message import yesno
 from stoqlib.lib.webservice import WebService
-from stoqlib.gui.base.dialogs import (get_dialog, run_dialog,
-                                      add_current_toplevel)
+from stoqlib.gui.base.dialogs import (get_dialog, run_dialog)
 from stoqlib.gui.base.infobar import InfoBar
 from stoqlib.gui.base.search import StoqlibSearchSlaveDelegate
 from stoqlib.gui.dialogs.csvexporterdialog import CSVExporterDialog
 from stoqlib.gui.help import show_contents, show_section
 from stoqlib.gui.introspection import introspect_slaves
+from stoqlib.gui.keybindings import get_accel, get_accels
+from stoqlib.gui.openbrowser import open_browser
 from stoqlib.gui.printing import print_report
 from stoqlib.gui.splash import hide_splash
 from stoqlib.domain.inventory import Inventory
@@ -87,24 +88,20 @@ class App(object):
         # shutdown and do_sync methods.
         self.main_window = window_class(self)
 
-    def show(self):
+    def show(self, params=None):
         if self.embedded:
             win = self.main_window.get_toplevel()
-            self.launcher.show_app(self.main_window, win.child)
+            self.launcher.show_app(self.main_window, win.child, params)
             win.hide()
         else:
             self.main_window.show()
 
-    def run(self):
-        self.show()
+    def run(self, params=None):
+        self.show(params)
 
     def hide(self):
         self.main_window.hide()
 
-    def shutdown(self, *args):
-        if reactor.running:
-            reactor.stop()
-
 
 class AppWindow(GladeDelegate):
     """ Class for the main window of applications.
@@ -119,7 +116,6 @@ class AppWindow(GladeDelegate):
 
     app_windows = []
     app_name = None
-    app_icon_name = None
     search = None
     gladefile = toplevel_name = ''
     title = ''
@@ -133,12 +129,10 @@ class AppWindow(GladeDelegate):
         self.current_app = None
         self.uimanager = self._create_ui_manager()
         self.accel_group = self.uimanager.get_accel_group()
-        # Cache to avoid duplicate queries on every row selection change
-        self._has_open_inventory =  Inventory.has_open(
-                            self.conn, api.get_current_branch(self.conn))
+        self._app_settings = api.user_settings.get('app-ui', {})
 
         self._create_ui_manager_ui()
-        GladeDelegate.__init__(self, delete_handler=self._on_delete_handler,
+        GladeDelegate.__init__(self,
                                keyactions=keyactions,
                                gladefile=self.gladefile,
                                toplevel_name=self.toplevel_name)
@@ -166,7 +160,6 @@ class AppWindow(GladeDelegate):
         toplevel = self.get_toplevel()
         toplevel.connect('delete-event', self._on_toplevel__delete_event)
         toplevel.connect('configure-event', self._on_toplevel__configure)
-        add_current_toplevel(toplevel)
         if self.size:
             toplevel.set_size_request(*self.size)
         toplevel.set_title(self.get_title())
@@ -191,25 +184,45 @@ class AppWindow(GladeDelegate):
         if not stoq.stable and not api.is_developer_mode():
             self._display_unstable_version_message()
 
+        # Initial fullscreen state for launcher must be handled
+        # separate since the window is not realized when the state loading
+        # is run in hide_app() the first time.
+        window = self.get_toplevel()
+        window.realize()
+        self.ToggleFullscreen.set_active(
+            self._app_settings.get('show-fullscreen', False))
+        self.ToggleFullscreen.notify('active')
+
     def _create_shared_actions(self):
         if self.app.name != 'launcher':
             return
+        group = get_accels('app.common')
         actions = [
             ('menubar', ),
             ('toolbar', ),
 
+            # Menus
             ('FileMenu', None, _("_File")),
             ('FileMenuNew', None),
             ("NewMenu", None, _("New")),
-            ('NewWindow', None, _("_Window"), '<control>n',
+
+            ('NewWindow', None, _("_Window"),
+             group.get('new_window'),
             _('Opens up a new window')),
-            ('Close', None, _('Close'), '<control>w',
+            ('Close', None, _('Close'),
+             group.get('close_window'),
             _('Close the current view and go back to the initial screen')),
-            ('ChangePassword', None, _('Change password...'), '',
+            ('ChangePassword', None, _('Change password...'),
+             group.get('change_password'),
             _('Change the password for the currently logged in user')),
-            ('SignOut', None, _('Sign out...'), '',
+            ('SignOut', None, _('Sign out...'),
+             group.get('sign_out'),
             _('Sign out the currently logged in user and login as another')),
-            ("Quit", gtk.STOCK_QUIT, _('Quit'), '<control>q',
+            ('Print', gtk.STOCK_PRINT, _("Print..."),
+             group.get('print')),
+            ('ExportCSV', gtk.STOCK_SAVE_AS, _('Export CSV...')),
+            ("Quit", gtk.STOCK_QUIT, _('Quit'),
+             group.get('quit'),
              _('Exit the application')),
 
             # Edit
@@ -224,11 +237,14 @@ class AppWindow(GladeDelegate):
 
             # Help
             ("HelpMenu", None, _("_Help")),
-            ("HelpContents", gtk.STOCK_HELP, _("Contents"), '<Shift>F1'),
+            ("HelpContents", gtk.STOCK_HELP, _("Contents"),
+             group.get('help_contents')),
             ("HelpTranslate", None, _("Translate Stoq..."), None,
              _("Translate this application online")),
             ("HelpSupport", None, _("Get support online..."), None,
              _("Get support for Stoq online")),
+            ("HelpChat", None, _("Online chat..."), None,
+             _("Talk about Stoq online")),
             ("HelpAbout", gtk.STOCK_ABOUT),
 
             # Toolbar
@@ -237,20 +253,21 @@ class AppWindow(GladeDelegate):
             ]
         self.add_ui_actions(None, actions, filename='launcher.xml')
         self.Close.set_sensitive(False)
-        toogle_actions = [
-            ('ToggleToolbar', None, _("_Toolbar"), '',
+        toggle_actions = [
+            ('ToggleToolbar', None, _("_Toolbar"),
+             group.get('toggle_toolbar'),
              _('Show or hide the toolbar')),
-            ('ToggleStatusbar', None, _("_Statusbar"), '',
+            ('ToggleStatusbar', None, _("_Statusbar"),
+             group.get('toggle_statusbar'),
              _('Show or hide the statusbar')),
-            ('ToggleFullscreen', None, _("_Fullscreen"), 'F11',
+            ('ToggleFullscreen', None, _("_Fullscreen"),
+             group.get('toggle_fullscreen'),
              _('Enter or leave fullscreen mode')),
             ]
-        self.add_ui_actions('', toogle_actions, 'ToogleActions',
-                            'toogle')
-
-        self.ToggleToolbar.props.active = True
-        self.ToggleStatusbar.props.active = True
+        self.add_ui_actions('', toggle_actions, 'ToggleActions',
+                            'toggle')
 
+        self.Print.set_short_label(_("Print"))
         self.add_tool_menu_actions([
             ("NewToolItem", _("New"), '', gtk.STOCK_NEW),
             ("SearchToolItem", _("Search"), None, gtk.STOCK_FIND),
@@ -267,11 +284,11 @@ class AppWindow(GladeDelegate):
             self._on_uimanager__disconnect_proxy)
 
         self.ToggleToolbar.connect(
-            'toggled', self._on_ToggleToolbar__toggled)
+            'notify::active', self._on_ToggleToolbar__notify_active)
         self.ToggleStatusbar.connect(
-            'toggled', self._on_ToggleStatusbar__toggled)
+            'notify::active', self._on_ToggleStatusbar__notify_active)
         self.ToggleFullscreen.connect(
-            'toggled', self._on_ToggleFullscreen__toggled)
+            'notify::active', self._on_ToggleFullscreen__notify_active)
 
         self.NewToolItem.connect(
             'activate', self._on_NewToolItem__activate)
@@ -285,6 +302,10 @@ class AppWindow(GladeDelegate):
             'activate', self._on_ChangePassword__activate)
         self.SignOut.connect(
             'activate', self._on_SignOut__activate)
+        self.Print.connect(
+            'activate', self._on_Print__activate)
+        self.ExportCSV.connect(
+            'activate', self._on_ExportCSV__activate)
         self.Quit.connect(
             'activate', self._on_Quit__activate)
 
@@ -296,6 +317,8 @@ class AppWindow(GladeDelegate):
             'activate', self._on_HelpTranslate__activate)
         self.HelpSupport.connect(
             'activate', self._on_HelpSupport__activate)
+        self.HelpChat.connect(
+            'activate', self._on_HelpChat__activate)
         self.HelpAbout.connect(
             'activate', self._on_HelpAbout__activate)
 
@@ -307,14 +330,7 @@ class AppWindow(GladeDelegate):
         self.main_vbox.pack_start(toolbar, False, False)
         self.main_vbox.reorder_child(toolbar, 1)
 
-        # Disable border on statusbar
-        children = self.statusbar.get_children()
-        if children and isinstance(children[0], gtk.Frame):
-            frame = children[0]
-            frame.set_shadow_type(gtk.SHADOW_NONE)
-
-        user = api.get_current_user(self.conn)
-        self.statusbar.push(0, _("User: %s") % (user.person.name, ))
+        self._prepare_statusbar()
 
         # FIXME: For some reason, without this hack, some apps like Stock and
         #        Purchase shows an extra search tool menu labeled 'empty'
@@ -350,7 +366,7 @@ class AppWindow(GladeDelegate):
         if not api.sysparam(self.conn).DEMO_MODE:
             return
 
-        if api.config.get('UI', 'hide_demo_warning') == 'True':
+        if api.user_settings.get('hide-demo-warning'):
             return
 
         button_label = _('Enable production mode')
@@ -447,17 +463,18 @@ class AppWindow(GladeDelegate):
 
     def _show_uri(self, uri):
         toplevel = self.get_toplevel()
-        gtk.show_uri(toplevel.get_screen(), uri, gtk.gdk.CURRENT_TIME)
+        open_browser(uri, toplevel.get_screen())
 
     def _new_window(self):
         self.app.shell.run()
 
     def _restore_window_size(self):
+        d = api.user_settings.get('launcher-geometry', {})
         try:
-            width = int(api.config.get('Launcher', 'window_width') or -1)
-            height = int(api.config.get('Launcher', 'window_height') or -1)
-            x = int(api.config.get('Launcher', 'window_x') or -1)
-            y = int(api.config.get('Launcher', 'window_y') or -1)
+            width = int(d.get('width', -1))
+            height = int(d.get('height', -1))
+            x = int(d.get('x', -1))
+            y = int(d.get('y', -1))
         except ValueError:
             pass
         toplevel = self.get_toplevel()
@@ -466,11 +483,58 @@ class AppWindow(GladeDelegate):
             toplevel.move(x, y)
 
     def _save_window_size(self):
-        api.config.set('Launcher', 'window_width', str(self._width))
-        api.config.set('Launcher', 'window_height', str(self._height))
-        api.config.set('Launcher', 'window_x', str(self._x))
-        api.config.set('Launcher', 'window_y', str(self._y))
-        api.config.flush()
+        if not hasattr(self, '_width'):
+            return
+        # Do not save the size of the window when we are in fullscreen
+        window = self.get_toplevel()
+        if window.window.get_state() & gtk.gdk.WINDOW_STATE_FULLSCREEN:
+            return
+        d = api.user_settings.get('launcher-geometry', {})
+        d['width'] = str(self._width)
+        d['height'] = str(self._height)
+        d['x'] = str(self._x)
+        d['y'] = str(self._y)
+
+    def _prepare_statusbar(self):
+        # Disable border on statusbar
+        children = self.statusbar.get_children()
+        if children and isinstance(children[0], gtk.Frame):
+            frame = children[0]
+            frame.set_shadow_type(gtk.SHADOW_NONE)
+
+        # Setup the message area, more complicated than it
+        # should be since we're maintaining support for
+        # PyGTK 2.17
+        if hasattr(self.statusbar, 'get_message_area'):
+            area = self.statusbar.get_message_area()
+        else:
+            area = gtk.HBox(False, 4)
+
+            frame = self.statusbar.get_children()[0]
+            label = frame.get_child()
+            frame.remove(label)
+            frame.add(area)
+
+            area.add(label)
+            area.show()
+
+        self.statusbar_message_area = area
+
+        # Set the initial text, the currently logged in user
+        user = api.get_current_user(self.conn)
+        self.statusbar.push(0, _("User: %s") % (user.person.name, ))
+
+    def _empty_message_area(self):
+        area = self.get_statusbar_message_area()
+        for child in area.get_children()[1:]:
+            child.destroy()
+
+    def _update_toggle_actions(self, app_name):
+        self._current_app_settings = d = self._app_settings.setdefault(app_name, {})
+        self.ToggleToolbar.set_active(d.get('show-toolbar', True))
+        self.ToggleStatusbar.set_active(d.get('show-statusbar', True))
+        self.ToggleToolbar.notify('active')
+        self.ToggleStatusbar.notify('active')
 
     #
     # Overridables
@@ -488,9 +552,11 @@ class AppWindow(GladeDelegate):
         in the instance.
         """
 
-    def activate(self):
+    def activate(self, params):
         """This is when you switch to an application.
-        You should setup widget sensitivity here and refresh lists etc"""
+        You should setup widget sensitivity here and refresh lists etc
+        @params: an dictionary with optional parameters.
+        """
 
     def setup_focus(self):
         """Define this method on child when it's needed.
@@ -532,10 +598,21 @@ class AppWindow(GladeDelegate):
         """Called when the Search toolbar item is activated"""
         raise NotImplementedError
 
+    def print_activate(self):
+        """Called when the Print toolbar item is activated"""
+        raise NotImplementedError
+
+    def export_csv_activate(self):
+        """Called when the Export menu item is activated"""
+        raise NotImplementedError
+
     #
     # Public API
     #
 
+    def get_statusbar_message_area(self):
+        return self.app.launcher.statusbar_message_area
+
     def print_report(self, report_class, *args, **kwargs):
         filters = self.search.get_search_filters()
         if filters:
@@ -543,13 +620,6 @@ class AppWindow(GladeDelegate):
 
         print_report(report_class, *args, **kwargs)
 
-    def toggle_fullscreen(self):
-        window = self.get_toplevel()
-        if window.window.get_state() & gtk.gdk.WINDOW_STATE_FULLSCREEN:
-            window.unfullscreen()
-        else:
-            window.fullscreen()
-
     def set_sensitive(self, widgets, value):
         """Set the C{widgets} sensitivity based on C{value}
 
@@ -603,8 +673,10 @@ class AppWindow(GladeDelegate):
         ag = gtk.ActionGroup(name)
         if action_type == 'normal':
             ag.add_actions(actions)
-        elif action_type == 'toogle':
+        elif action_type == 'toggle':
             ag.add_toggle_actions(actions)
+        elif action_type == 'radio':
+            ag.add_radio_actions(actions)
         else:
             raise ValueError(action_type)
         self.uimanager.insert_action_group(ag, 0)
@@ -642,7 +714,8 @@ class AppWindow(GladeDelegate):
         </menubar>
         </ui>"""
         help_help_actions = [
-            ("HelpHelp", None, label, 'F1',
+            ("HelpHelp", None, label,
+             get_accel('app.common.help'),
              _("Show help for this application"),
              on_HelpHelp__activate),
             ]
@@ -667,10 +740,8 @@ class AppWindow(GladeDelegate):
         self.add_ui_actions(ui_string, actions, 'DebugActions')
 
     def has_open_inventory(self, from_cache=True):
-        if not from_cache:
-            self._has_open_inventory =  Inventory.has_open(
-                            self.conn, api.get_current_branch(self.conn))
-        return self._has_open_inventory
+        return Inventory.has_open(self.conn,
+                                  api.get_current_branch(self.conn))
 
     def check_open_inventory(self):
         """Checks if there is an open inventory.
@@ -682,7 +753,7 @@ class AppWindow(GladeDelegate):
         """
         inventory_bar = getattr(self, 'inventory_bar', None)
 
-        if self.has_open_inventory(from_cache=False):
+        if self.has_open_inventory():
             if inventory_bar:
                 inventory_bar.show()
             else:
@@ -727,22 +798,29 @@ class AppWindow(GladeDelegate):
         button = new_item.get_children()[0].get_children()[0]
         button.set_sensitive(sensitive)
 
-    def show_app(self, app, app_window):
+    def show_app(self, app, app_window, params=None):
         app_window.reparent(self.application_box)
         self.application_box.set_child_packing(app_window, True, True, 0,
                                                gtk.PACK_START)
         self.Close.set_sensitive(True)
         self.ChangePassword.set_visible(False)
         self.SignOut.set_visible(False)
+        self.Print.set_visible(True)
+        self.Print.set_sensitive(False)
+        self.ExportCSV.set_visible(True)
+        self.ExportCSV.set_sensitive(False)
         self.Quit.set_visible(False)
         self.NewToolItem.set_tooltip("")
         self.NewToolItem.set_sensitive(True)
         self.SearchToolItem.set_tooltip("")
         self.SearchToolItem.set_sensitive(True)
 
+        self._update_toggle_actions(app.app.name)
+
         self.get_toplevel().set_title(app.get_title())
         self.application_box.show()
-        app.activate()
+        app.activate(params or {})
+
         self.uimanager.ensure_update()
         while gtk.events_pending():
             gtk.main_iteration()
@@ -766,9 +844,7 @@ class AppWindow(GladeDelegate):
             self.current_app = None
 
         self.get_toplevel().set_title(self.get_title())
-        message_area = self.statusbar
-        for child in message_area.get_children()[1:]:
-            child.destroy()
+        self._empty_message_area()
         for item in self._tool_items:
             item.destroy()
         self._tool_items = []
@@ -776,21 +852,32 @@ class AppWindow(GladeDelegate):
         self.ChangePassword.set_visible(True)
         self.SignOut.set_visible(True)
         self.Quit.set_visible(True)
+        self.Print.set_sensitive(False)
+        self.Print.set_visible(False)
+        self.ExportCSV.set_visible(False)
+        self.ExportCSV.set_sensitive(False)
         self.set_new_menu_sensitive(True)
         self.NewToolItem.set_tooltip(_("Open a new window"))
         self.SearchToolItem.set_tooltip("")
         self.SearchToolItem.set_sensitive(False)
+        self._update_toggle_actions('launcher')
 
     #
     # AppWindow
     #
 
     def shutdown_application(self, *args):
+        log.debug("Shutting down application")
         if not self.can_close_application():
             return False
 
         if self.current_app and self.current_app.search:
             self.current_app.search.save_columns()
+
+        self._save_window_size()
+        if self.app.name == 'launcher':
+            log.debug("Flushing user settings")
+            api.user_settings.flush()
         return True
 
     #
@@ -803,9 +890,6 @@ class AppWindow(GladeDelegate):
             self.hide_app()
         return True
 
-    def key_control_F11(self):
-        self.toggle_fullscreen()
-
     def _on_toplevel__configure(self, widget, event):
         rect = widget.window.get_frame_extents()
         self._x = rect.x
@@ -823,8 +907,8 @@ class AppWindow(GladeDelegate):
         if AppWindow.app_windows:
             return
 
-        self._save_window_size()
-        raise SystemExit
+        if self.shutdown_application():
+            reactor.stop()
 
     def _on_menu_item__select(self, menuitem, tooltip):
         self.statusbar.push(-1, tooltip)
@@ -856,8 +940,12 @@ class AppWindow(GladeDelegate):
         if not tooltip:
             return
         if isinstance(widget, gtk.MenuItem):
-            widget.disconnect_by_func(self._on_menu_item__select)
-            widget.disconnect_by_func(self._on_menu_item__deselect)
+            try:
+                widget.disconnect_by_func(self._on_menu_item__select)
+                widget.disconnect_by_func(self._on_menu_item__deselect)
+            except TypeError:
+                # Maybe it was already disconnected
+                pass
         elif isinstance(widget, gtk.ToolItem):
             try:
                 widget.child.disconnect_by_func(
@@ -884,6 +972,14 @@ class AppWindow(GladeDelegate):
     def _on_NewWindow__activate(self, action):
         self._new_window()
 
+    def _on_Print__activate(self, action):
+        if self.current_app:
+            self.current_app.print_activate()
+
+    def _on_ExportCSV__activate(self, action):
+        if self.current_app:
+            self.current_app.export_csv_activate()
+
     def _on_Close__activate(self, action):
         if self.current_app and self.current_app.shutdown_application():
             self.hide_app()
@@ -905,8 +1001,8 @@ class AppWindow(GladeDelegate):
         if self.current_app and not self.current_app.shutdown_application():
             return
 
-        self._save_window_size()
-        raise SystemExit
+        if self.shutdown_application():
+            reactor.stop()
 
     # View
 
@@ -915,15 +1011,30 @@ class AppWindow(GladeDelegate):
 
     # Edit
 
-    def _on_ToggleToolbar__toggled(self, action):
+    def _on_ToggleToolbar__notify_active(self, action, pspec):
         toolbar = self.uimanager.get_widget('/toolbar')
         toolbar.set_visible(action.get_active())
+        self._current_app_settings['show-toolbar'] = action.get_active()
 
-    def _on_ToggleStatusbar__toggled(self, action):
+    def _on_ToggleStatusbar__notify_active(self, action, pspec):
         self.statusbar.set_visible(action.get_active())
+        self._current_app_settings['show-statusbar'] = action.get_active()
 
-    def _on_ToggleFullscreen__toggled(self, action):
-        self.toggle_fullscreen()
+    def _on_ToggleFullscreen__notify_active(self, action, spec):
+        window = self.get_toplevel()
+        if not window.get_realized():
+            return
+        is_active = action.get_active()
+        is_fullscreen = window.window.get_state() & gtk.gdk.WINDOW_STATE_FULLSCREEN
+        if is_active != is_fullscreen:
+            if is_active:
+                window.fullscreen()
+            else:
+                window.unfullscreen()
+
+        # This is shared between apps, since it's weird to change fullscreen
+        # between applications
+        self._app_settings['show-fullscreen'] = is_active
 
     # Help
 
@@ -933,6 +1044,9 @@ class AppWindow(GladeDelegate):
     def _on_HelpTranslate__activate(self, action):
         self._show_uri("https://translations.launchpad.net/stoq")
 
+    def _on_HelpChat__activate(self, action):
+        self._show_uri("http://chat.stoq.com.br/")
+
     def _on_HelpSupport__activate(self, action):
         self._show_uri("http://www.stoq.com.br/suporte")
 
@@ -959,14 +1073,8 @@ class AppWindow(GladeDelegate):
         restart_stoq_atexit()
         api.config.set('Database', 'enable_production', 'True')
         api.config.flush()
-        self.shutdown_application()
-        raise SystemExit
-
-    def _on_delete_handler(self, *args):
-        self.shutdown_application()
-
-    def _on_quit_action__clicked(self, *args):
-        self.shutdown_application()
+        if self.shutdown_application():
+            reactor.stop()
 
 
 class SearchableAppWindow(AppWindow):
@@ -975,15 +1083,20 @@ class SearchableAppWindow(AppWindow):
 
     @cvar search_table: The we will query on to perform the search
     @cvar search_label: Label left of the search entry
+    @cvar report_table: the report class for printing the object list
+        embedded on app.
     """
 
     search_table = None
     search_label = _('Search:')
+    report_table = None
 
     def __init__(self, app):
         if self.search_table is None:
             raise TypeError("%r must define a search_table attribute" % self)
 
+        self._loading_filters = False
+
         self.executer = ORMObjectQueryExecuter(api.get_connection())
         self.executer.set_table(self.search_table)
 
@@ -997,13 +1110,46 @@ class SearchableAppWindow(AppWindow):
         self.set_text_field_label(self.search_label)
 
         AppWindow.__init__(self, app)
-
         self.attach_slave('search_holder', self.search)
 
         self.create_filters()
+        self._restore_filter_settings()
 
         self.search.focus_search_entry()
 
+    def _save_filter_settings(self):
+        if self._loading_filters:
+            return
+        filter_states = self.search.search.get_filter_states()
+        settings = self._app_settings.setdefault(self.app.name, {})
+        settings['filter-states'] = filter_states
+
+    def _restore_filter_settings(self):
+        self._loading_filters = True
+        settings = self._app_settings.setdefault(self.app.name, {})
+        filter_states = settings.get('filter-states')
+        if filter_states is not None:
+            self.search.search.set_filter_states(filter_states)
+        self._loading_filters = False
+
+    #
+    # AppWindow hooks
+    #
+
+    def print_activate(self):
+        if self.results.get_selection_mode() == gtk.SELECTION_MULTIPLE:
+            results = self.results.get_selected_rows()
+        else:
+            result = self.results.get_selected()
+            results = [result] if result else None
+        results = results or list(self.results)
+
+        self.print_report(self.report_table, self.results, results,
+                          do_footer=False)
+
+    def export_csv_activate(self):
+        self.export_csv()
+
     #
     # Public API
     #
@@ -1080,8 +1226,10 @@ class SearchableAppWindow(AppWindow):
     def _on_search__search_completed(self, search, results, states):
         self.search_completed(results, states)
 
-    def on_ExportCSV__activate(self, action):
-        self.export_csv()
+        has_results = len(results)
+        for widget in (self.app.launcher.Print, self.app.launcher.ExportCSV):
+            widget.set_sensitive(has_results)
+        self._save_filter_settings()
 
 
 class VersionChecker(object):
@@ -1122,10 +1270,9 @@ class VersionChecker(object):
 
     def _on_response_done(self, details):
         self._check_details(details['version'])
-        api.config.set('General', 'last-version-check',
-                       datetime.date.today().strftime('%Y-%m-%d'))
-        api.config.set('General', 'latest-version', details['version'])
-        api.config.flush()
+        api.user_settings.set('last-version-check',
+                              datetime.date.today().strftime('%Y-%m-%d'))
+        api.user_settings.set('latest-version', details['version'])
 
     #
     #   Public API
@@ -1135,7 +1282,7 @@ class VersionChecker(object):
         if api.is_developer_mode():
             return
         log.debug('Checking version')
-        date = api.config.get('General', 'last-version-check')
+        date = api.user_settings.get('last-version-check')
         if date:
             check_date = datetime.datetime.strptime(date, '%Y-%m-%d')
             diff = datetime.date.today() - check_date.date()
@@ -1144,6 +1291,6 @@ class VersionChecker(object):
         else:
             return self._download_details()
 
-        latest_version = api.config.get('General', 'latest-version')
+        latest_version = api.user_settings.get('latest-version')
         if latest_version:
             self._check_details(latest_version)
