@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2005-2011 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2005-2012 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -37,12 +37,15 @@ from stoqlib.domain.inventory import Inventory
 from stoqlib.domain.person import Person
 from stoqlib.domain.product import ProductStockItem
 from stoqlib.exceptions import DatabaseInconsistency
-from stoq.gui.application import SearchableAppWindow
 from stoqlib.gui.dialogs.openinventorydialog import OpenInventoryDialog
 from stoqlib.gui.dialogs.productadjustmentdialog import ProductsAdjustmentDialog
 from stoqlib.gui.dialogs.productcountingdialog import ProductCountingDialog
+from stoqlib.gui.keybindings import get_accels
 from stoqlib.lib.message import warning, yesno
 from stoqlib.reporting.product import ProductCountingReport
+from stoqlib.reporting.inventory import InventoryReport
+
+from stoq.gui.application import SearchableAppWindow
 
 _ = gettext.gettext
 
@@ -52,10 +55,10 @@ class InventoryApp(SearchableAppWindow):
     # TODO: Change all widget.set_sensitive to self.set_sensitive([widget])
 
     app_name = _('Inventory')
-    app_icon_name = 'stoq-inventory-app'
     gladefile = "inventory"
     search_table = Inventory
     search_labels = _('Matching:')
+    report_table = InventoryReport
     embedded = True
 
     #
@@ -63,30 +66,34 @@ class InventoryApp(SearchableAppWindow):
     #
 
     def create_actions(self):
+        group = get_accels('app.inventory')
         actions = [
-            ('menubar', None, ''),
-            # Inventory
-            ('NewInventory', None, _('Open I_nventry'), '<Control>i',
+            # File
+            ('NewInventory', None, _('Inventory...'),
+             group.get('new_inventory'),
              _('Create a new inventory for product counting')),
-            ('CountingAction', gtk.STOCK_INDEX, _('_Count inventory...'),
-             '<Control>c',
+
+            # Inventory
+            ('InventoryMenu', None, _('Inventory')),
+            ('CountingAction', gtk.STOCK_INDEX, _('_Count...'),
+             group.get('inventory_count'),
              _('Register the actual stock of products in the selected '
                'inventory')),
-            ('AdjustAction', gtk.STOCK_CONVERT, _('_Adjust inventory...'),
-             '<Control>a',
+            ('AdjustAction', gtk.STOCK_CONVERT, _('_Adjust...'),
+             group.get('inventory_adjust'),
              _('Adjust the stock accordingly to the counting in the selected '
                'inventory')),
-            ('Cancel', gtk.STOCK_CANCEL, _('Cancel inventory'), '',
+            ('Cancel', gtk.STOCK_CANCEL, _('Cancel...'),
+             group.get('inventory_cancel'),
              _('Cancel the selected inventory')),
-            ('Print', gtk.STOCK_PRINT, _('Print inventory'), '',
-             _('Print the product listing for the selected inventory '
-               'to be used for counting')),
-            ('ExportCSV', gtk.STOCK_SAVE_AS, _('Export CSV...')),
+            ('PrintProductListing', gtk.STOCK_PRINT,
+             _('Print product listing...'),
+             group.get('inventory_print'),
+             _('Print the product listing for this inventory'))
         ]
         self.inventory_ui = self.add_ui_actions('', actions,
                                                 filename='inventory.xml')
-        self.set_help_section(_("Inventory help"),
-                              'inventario-inicio')
+        self.set_help_section(_("Inventory help"), 'app-inventory')
 
         self.AdjustAction.set_short_label(_("Adjust"))
         self.CountingAction.set_short_label(_("Count"))
@@ -96,12 +103,14 @@ class InventoryApp(SearchableAppWindow):
         self.Cancel.props.is_important = True
 
     def create_ui(self):
-        self.search.search.search_button.hide()
-        self.app.launcher.add_new_items([self.NewInventory])
+        self.popup = self.uimanager.get_widget('/InventorySelection')
 
-    def activate(self):
+        self.app.launcher.add_new_items([self.NewInventory])
+        self.app.launcher.Print.set_tooltip(
+            _("Print a report of these inventories"))
+
+    def activate(self, params):
         # Avoid letting this sensitive if has-rows is never emitted
-        self.Print.set_sensitive(False)
         self.search.refresh()
         self._update_widgets()
         self.app.launcher.SearchToolItem.set_sensitive(False)
@@ -142,10 +151,10 @@ class InventoryApp(SearchableAppWindow):
                 Column('branch.person.name', title=_('Branch'),
                        data_type=str, expand=True),
                 SearchColumn('open_date', title=_('Opened'),
-                       long_title='Date Opened',
+                       long_title=_('Date Opened'),
                        data_type=datetime.date, width=120),
-                SearchColumn('close_date', title=_(u'Closed'),
-                       long_title='Date Closed',
+                SearchColumn('close_date', title=_('Closed'),
+                       long_title=_('Date Closed'),
                        data_type=datetime.date, width=120)]
 
     #
@@ -179,7 +188,6 @@ class InventoryApp(SearchableAppWindow):
             has_open = selected.is_open()
             has_adjusted = selected.has_adjusted_items()
 
-        self.set_sensitive([self.Print], has_open)
         self.set_sensitive([self.Cancel], has_open and not has_adjusted)
         self.set_sensitive([self.NewInventory], self._can_open())
         self.set_sensitive([self.CountingAction], has_open)
@@ -270,10 +278,13 @@ class InventoryApp(SearchableAppWindow):
     def on_results__selection_changed(self, results, product):
         self._update_widgets()
 
+    def on_results__right_click(self, results, result, event):
+        self.popup.popup(None, None, None, event.button, event.time)
+
     def on_Cancel__activate(self, widget):
         self._cancel_inventory()
 
-    def on_Print__activate(self, button):
+    def on_PrintProductListing__activate(self, button):
         selected = self.results.get_selected()
         sellables = list(self._get_sellables_by_inventory(selected))
         if not sellables:
