@@ -28,6 +28,7 @@ import operator
 import gtk
 from kiwi.component import get_utility
 from stoqlib.api import api
+from stoqlib.gui.base.dialogs import add_current_toplevel
 from stoqlib.lib.interfaces import IApplicationDescriptions
 from stoq.gui.application import AppWindow
 from stoq.lib.applist import Application
@@ -66,10 +67,12 @@ class Launcher(AppWindow):
         return self.app_name
 
     def create_ui(self):
+        toplevel = self.get_toplevel().get_toplevel()
+        add_current_toplevel(toplevel)
         self.model.set_sort_column_id(COL_LABEL, gtk.SORT_ASCENDING)
         self.iconview.set_markup_column(COL_LABEL)
         self.iconview.set_pixbuf_column(COL_PIXBUF)
-        if hasattr(self.iconview, 'set_item_orientation'):
+        if hasattr(self.iconview, "set_item_orientation"):
             self.iconview.set_item_orientation(gtk.ORIENTATION_HORIZONTAL)
         self.iconview.set_item_width(300)
         self.iconview.set_selection_mode(gtk.SELECTION_BROWSE)
@@ -88,19 +91,34 @@ class Launcher(AppWindow):
     # Public API
     #
 
-    def show_app(self, app, app_window):
+    def show_app(self, app, app_window, params=None):
         self.iconview_vbox.hide()
-        super(Launcher, self).show_app(app, app_window)
+        super(Launcher, self).show_app(app, app_window, params)
 
     def hide_app(self):
         super(Launcher, self).hide_app()
         self.iconview_vbox.show()
         self.iconview.grab_focus()
 
+    def run_app_by_name(self, app_name, params=None):
+        self.hide_app()
+        app = self._get_app_by_name(app_name)
+        if app is None:
+            raise ValueError(app_name)
+        return self.shell.run_embedded(app, self, params)
+
     #
     # Private
     #
 
+    def _get_app_by_name(self, app_name):
+        for row in self.model:
+            if row[COL_APP].name == app_name:
+                return row[COL_APP]
+
+    def _run_app(self, app):
+        self.shell.run_embedded(app, self)
+
     def _get_available_applications(self):
         user = api.get_current_user(self.conn)
 
@@ -131,4 +149,4 @@ class Launcher(AppWindow):
 
     def on_iconview__item_activated(self, iconview, path):
         app = self.model[path][COL_APP]
-        self.shell.run_embedded(app, self)
+        self._run_app(app)
