@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2007 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2007-2012 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -35,25 +35,27 @@ import gtk
 from kiwi.datatypes import currency
 from kiwi.enums import SearchFilterPosition
 from kiwi.python import all
-from kiwi.ui.search import ComboSearchFilter
+from kiwi.ui.search import ComboSearchFilter, DateSearchFilter
 from kiwi.ui.objectlist import Column, SearchColumn
+from kiwi.ui.gadgets import render_pixbuf
 from stoqlib.api import api
 from stoqlib.domain.payment.operation import register_payment_operations
 from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.payment.views import OutPaymentView
 from stoqlib.domain.purchase import PurchaseOrder
 from stoqlib.gui.base.dialogs import run_dialog
-from stoqlib.gui.base.gtkadds import render_pixbuf
 from stoqlib.gui.dialogs.paymentchangedialog import (PaymentDueDateChangeDialog,
                                                      PaymentStatusChangeDialog)
 from stoqlib.gui.dialogs.paymentcommentsdialog import PaymentCommentsDialog
 from stoqlib.gui.dialogs.paymentflowhistorydialog import PaymentFlowHistoryDialog
 from stoqlib.gui.editors.paymenteditor import OutPaymentEditor
 from stoqlib.gui.editors.paymentseditor import PaymentsEditor
+from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.printing import print_report
 from stoqlib.gui.search.paymentsearch import OutPaymentBillCheckSearch
+from stoqlib.lib.message import warning
 from stoqlib.reporting.payment import PayablePaymentReport
-from stoqlib.reporting.payment_receipt import PaymentReceipt
+from stoqlib.reporting.payments_receipt import OutPaymentReceipt
 
 from stoq.gui.application import SearchableAppWindow
 from stoqlib.gui.slaves.installmentslave import PurchaseInstallmentConfirmationSlave
@@ -66,10 +68,10 @@ class PayableApp(SearchableAppWindow):
     # TODO: Change all widget.set_sensitive to self.set_sensitive([widget])
 
     app_name = _('Accounts payable')
-    app_icon_name = 'stoq-payable-app'
     gladefile = 'payable'
     search_table = OutPaymentView
     search_label = _('matching:')
+    report_table = PayablePaymentReport
     embedded = True
 
     #
@@ -77,68 +79,77 @@ class PayableApp(SearchableAppWindow):
     #
 
     def create_actions(self):
+        group = get_accels('app.payable')
+
         actions = [
-            ('menubar', None, ''),
-
-            # Payable
-            ('AddPayment', gtk.STOCK_ADD, _('Account payable...'), '<Control>p',
+            # File
+            ('AddPayment', gtk.STOCK_ADD, _('Account payable...'),
+             group.get('add_payable'),
              _('Create a new account payable')),
-            ('CancelPayment', gtk.STOCK_REMOVE, _('Cancel payment...'), '',
-             _('Cancel the selected payment')),
-            ('SetNotPaid', gtk.STOCK_UNDO, _('Set as not paid...'), '',
-             _('Mark the selected payment as not paid')),
-            ('ChangeDueDate', gtk.STOCK_REFRESH, _('Change due date...'), '',
-             _('Change the due date of the selected payment')),
-            ('Comments', None, _('Comments...'), '',
-             _('Add comments to the selected payment')),
-
-            ('PrintReceipt', None, _('Print _receipt'), '<Control>r',
-             _('Print a receipt for the selected payment')),
             ('PaymentFlowHistory', None, _('Payment _flow history...'),
-             '<Control>f',
+             group.get('payment_flow_history'),
              _('Show a report of payment expected to receive grouped by day')),
 
-            ('ExportCSV', gtk.STOCK_SAVE_AS, _('Export CSV...')),
-
-            # Search
-            ('BillCheckSearch', None, _('Bills and checks...'), '',
-             _('Search for bills and checks')),
-
             # Payment
             ('PaymentMenu', None, _('Payment')),
-
-            # Toolbar
-            ('PrintReport', gtk.STOCK_PRINT, _('Print'), '',
-             _('Print a report for this payment listing')),
-            ('Pay', gtk.STOCK_APPLY, _('Pay'), '',
-             _('Pay the order associated with the selected payment')),
-            ('Edit', gtk.STOCK_EDIT, _('Edit'), '',
-             _('Edit the selected payment details')),
-            ('Details', gtk.STOCK_INFO, _('Details'), '',
+            ('Details', gtk.STOCK_INFO, _('Details...'),
+             group.get('payment_details'),
              _('Show details for the selected payment')),
+            ('Pay', gtk.STOCK_APPLY, _('Pay...'),
+             group.get('payment_pay'),
+             _('Pay the order associated with the selected payment')),
+            ('Edit', gtk.STOCK_EDIT, _('Edit...'),
+             group.get('payment_edit'),
+             _('Edit the selected payment details')),
+            ('CancelPayment', gtk.STOCK_REMOVE, _('Cancel...'),
+             group.get('payment_cancel'),
+             _('Cancel the selected payment')),
+            ('SetNotPaid', gtk.STOCK_UNDO, _('Set as not paid...'),
+             group.get('payment_set_not_paid'),
+             _('Mark the selected payment as not paid')),
+            ('ChangeDueDate', gtk.STOCK_REFRESH, _('Change due date...'),
+             group.get('payment_change_due_date'),
+             _('Change the due date of the selected payment')),
+            ('Comments', None, _('Comments...'),
+             group.get('payment_comments'),
+             _('Add comments to the selected payment')),
+            ('PrintReceipt', None, _('Print _receipt...'),
+             group.get('payment_print_receipt'),
+             _('Print a receipt for the selected payment')),
+
+            # Search
+            ('BillCheckSearch', None, _('Bills and checks...'),
+             group.get('search_bills'),
+             _('Search for bills and checks')),
         ]
+
         self.payable_ui = self.add_ui_actions(None, actions,
                                               filename='payable.xml')
-        self.set_help_section(_("Accounts payable help"),
-                              'pagar-inicio')
+        self.set_help_section(_("Accounts payable help"), 'app-payable')
+        self.Pay.set_short_label(_('Pay'))
+        self.Edit.set_short_label(_('Edit'))
+        self.Details.set_short_label(_('Details'))
         self.Pay.props.is_important = True
         self.popup = self.uimanager.get_widget('/PayableSelection')
 
     def create_ui(self):
-        self._setup_widgets()
-        self.search.search.search_button.hide()
-
-    def activate(self):
-        # Avoid letting this sensitive if has-rows is never emitted
-        self.PrintReport.set_sensitive(False)
-        self.search.refresh()
         self.app.launcher.add_new_items([self.AddPayment])
         self.app.launcher.NewToolItem.set_tooltip(self.AddPayment.get_tooltip())
         self.app.launcher.add_search_items([self.BillCheckSearch])
         self.app.launcher.SearchToolItem.set_tooltip(
             self.BillCheckSearch.get_tooltip())
+        self.app.launcher.Print.set_tooltip(
+            _("Print a report of these payments"))
         self.Pay.set_sensitive(False)
         self.PrintReceipt.set_sensitive(False)
+        self._setup_widgets()
+        self.search.search.results.set_cell_data_func(
+            self._on_results__cell_data_func)
+
+    def activate(self, params):
+        # FIXME: double negation is weird here
+        if not params.get('no-refresh'):
+            self.search.refresh()
         self._update_widgets()
 
     def deactivate(self):
@@ -156,14 +167,14 @@ class PayableApp(SearchableAppWindow):
 
     def create_filters(self):
         self.set_text_field_columns(['description', 'supplier_name'])
-        self.add_filter(
-            ComboSearchFilter(_('Show payments'),
-                              self._get_status_values()),
-            SearchFilterPosition.TOP, ['status'])
+        self.status_filter = ComboSearchFilter(_('Show payments'),
+                                               self._get_status_values())
+        self.add_filter(self.status_filter,
+                        SearchFilterPosition.TOP, ['status'])
 
     def get_columns(self):
-        return [SearchColumn('id', title=_('#'), long_title='Payment ID',
-                             width=60, data_type=int, sorted=True,
+        return [SearchColumn('id', title=_('#'), long_title=_('Payment ID'),
+                             width=60, data_type=int,
                              format='%04d'),
                 Column('color', title=_('Description'), width=20,
                        data_type=gtk.gdk.Pixbuf, format_func=render_pixbuf),
@@ -176,7 +187,8 @@ class PayableApp(SearchableAppWindow):
                              data_type=str, width=140,
                              ellipsize=pango.ELLIPSIZE_END),
                 SearchColumn('due_date', title=_('Due date'),
-                             data_type=datetime.date, width=100),
+                             data_type=datetime.date, width=100,
+                             sorted=True),
                 SearchColumn('paid_date', title=_('Paid date'),
                              data_type=datetime.date, width=100),
                 SearchColumn('status_str', title=_('Status'), width=100,
@@ -186,7 +198,24 @@ class PayableApp(SearchableAppWindow):
                 SearchColumn('value', title=_('Value'), data_type=currency,
                              width=90),
                 SearchColumn('paid_value', title=_('Paid'), data_type=currency,
-                              long_title='Paid value', width=90)]
+                             long_title=_('Paid value'), width=90),
+                SearchColumn('category', title=_('Category'), data_type=str,
+                             long_title=_('Payment category'), width=110,
+                             visible=False),
+                ]
+
+    #
+    # Public API
+    #
+
+    def search_for_date(self, date):
+        self.status_filter.select(None)
+        dfilter = DateSearchFilter(_("Paid or due date"))
+        dfilter.set_removable()
+        dfilter.mode.select_item_by_position(5)
+        self.add_filter(dfilter, columns=["paid_date", "due_date"])
+        dfilter.start_date.set_date(date)
+        self.search.refresh()
 
     #
     # Private
@@ -303,6 +332,17 @@ class PayableApp(SearchableAppWindow):
         """
         assert self._can_pay(payable_views)
 
+        # Do not allow confirming the payment if the purchase was not
+        # completely received.
+        purchase_order = payable_views[0].purchase
+
+        if (purchase_order and
+            api.sysparam(self.conn).BLOCK_INCOMPLETE_PURCHASE_PAYMENTS and
+            not purchase_order.status == PurchaseOrder.ORDER_CLOSED):
+
+            return warning(_("Can't confirm the payment if the purchase "
+                             "is not completely received yet."))
+
         with api.trans() as trans:
             payments = [trans.get(view.payment) for view in payable_views]
 
@@ -310,9 +350,9 @@ class PayableApp(SearchableAppWindow):
                        payments=payments)
 
         if trans.committed:
-            for view in payable_views:
-                view.sync()
-                self.results.update(view)
+            # We need to refresh the whole list as the payment(s) can possibly
+            # disappear for the selected view
+            self.refresh()
 
         self._update_widgets()
 
@@ -348,7 +388,7 @@ class PayableApp(SearchableAppWindow):
             return False
 
         purchase = payable_views[0].purchase_id
-        if purchase is None and respect_purchase:
+        if not purchase and len(payable_views) > 1:
             return False
 
         return all((view.purchase_id == purchase or not respect_purchase) and
@@ -375,12 +415,11 @@ class PayableApp(SearchableAppWindow):
         return all(view.sale == sale for view in payable_views)
 
     def _setup_widgets(self):
-        parent = self.app.launcher.statusbar
         self.results.set_selection_mode(gtk.SELECTION_MULTIPLE)
         self.search.set_summary_label(column='value',
                                       label='<b>Total:</b>',
                                       format='<b>%s</b>',
-                                      parent=parent)
+                                      parent=self.get_statusbar_message_area())
 
     def _update_widgets(self):
         selected = self.results.get_selected_rows()
@@ -414,8 +453,21 @@ class PayableApp(SearchableAppWindow):
     # Kiwi callbacks
     #
 
-    def on_results__has_rows(self, klist, has_rows):
-        self.PrintReport.set_sensitive(has_rows)
+    def _on_results__cell_data_func(self, column, renderer, pv, text):
+        if not isinstance(renderer, gtk.CellRendererText):
+            return text
+
+        if pv.paid_date and self.status_filter.get_state().value is None:
+            renderer.set_property('strikethrough', True)
+            renderer.set_property('strikethrough-set', True)
+        else:
+            renderer.set_property('strikethrough-set', False)
+        if not pv.paid_date and pv.due_date < datetime.datetime.now():
+            renderer.set_property('weight', pango.WEIGHT_BOLD)
+            renderer.set_property('weight-set', True)
+        else:
+            renderer.set_property('weight-set', False)
+        return text
 
     def on_results__row_activated(self, klist, payable_view):
         if self._can_show_details([payable_view]):
@@ -441,17 +493,13 @@ class PayableApp(SearchableAppWindow):
     def on_results__selection_changed(self, results, selected):
         self._update_widgets()
 
-    def on_PrintReport__activate(self, action):
-        payments = self.results.get_selected_rows() or list(self.results)
-        self.print_report(PayablePaymentReport, self.results,
-                          payments, do_footer=False)
-
     def on_PrintReceipt__activate(self, action):
         register_payment_operations()
         payment_views = self.results.get_selected_rows()
         payments = [v.payment for v in payment_views]
-        print_report(PaymentReceipt, payments=payments,
-                     purchase=payment_views[0].purchase)
+        date = datetime.date.today()
+        print_report(OutPaymentReceipt, payment=payments[0],
+                     order=payment_views[0].purchase, date=date)
 
     def on_PaymentFlowHistory__activate(self, action):
         self.run_dialog(PaymentFlowHistoryDialog, self.conn)
