@@ -55,6 +55,7 @@ from stoqlib.gui.base.gtkadds import button_set_image_with_label
 from stoqlib.gui.editors.deliveryeditor import DeliveryEditor
 from stoqlib.gui.editors.serviceeditor import ServiceItemEditor
 from stoqlib.gui.fiscalprinter import FiscalPrinterHelper
+from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.search.personsearch import ClientSearch
 from stoqlib.gui.search.productsearch import ProductSearch
 from stoqlib.gui.search.salesearch import (SaleSearch, DeliverySearch,
@@ -73,7 +74,7 @@ class _SaleItem(object):
         # Use only 3 decimal places for the quantity
         self.quantity = Decimal('%.3f' % quantity)
         self.sellable = sellable
-        self.description = sellable.base_sellable_info.description
+        self.description = sellable.description
         self.unit = sellable.get_unit_description()
         self.code = sellable.code
 
@@ -108,7 +109,6 @@ LOGO_HEIGHT = 32
 class PosApp(AppWindow):
 
     app_name = _('Point of Sales')
-    app_icon_name = 'stoq-pos-app'
     gladefile = "pos"
     embedded = True
 
@@ -128,33 +128,40 @@ class PosApp(AppWindow):
     #
 
     def create_actions(self):
+        group = get_accels('app.pos')
         actions = [
-            ('menubar', None, ''),
+            # File
+            ("TillOpen", None, _("Open Till..."),
+             group.get('till_open')),
+            ("TillClose", None, _("Close Till..."),
+             group.get('till_close')),
 
-            # Sales
-            ("SalesMenu", None, _("Sal_es")),
-            ('CancelOrder', None, _('Cancel Order'), '<Control><Alt>o'),
-            ('NewDelivery', None, _('New Delivery...'), '<Control>F5'),
-            ('ConfirmOrder', None, _('Confirm Order...'), '<Control>F10'),
+            # Order
+            ("OrderMenu", None, _("Order")),
+            ('ConfirmOrder', None, _('Confirm...'),
+             group.get('order_confirm')),
+            ('CancelOrder', None, _('Cancel...'),
+             group.get('order_cancel')),
+            ('NewDelivery', None, _('Create delivery...'),
+             group.get('order_create_delivery')),
 
             # Search
-            ("Sales", None, _("Sales..."), '<Control><Alt>a'),
+            ("Sales", None, _("Sales..."),
+             group.get('search_sales')),
             ("SoldItemsByBranchSearch", None, _("Sold Items by Branch..."),
-                '<Contrl><Alt>a'),
-            ("Clients", None, _("Clients..."), '<Control><Alt>c'),
-            ("ProductSearch", None, _("Products..."), '<Control><Alt>p'),
-            ("ServiceSearch", None, _("Services..."), '<Contro><Alt>s'),
-            ("DeliverySearch", None, _("Deliveries..."), '<Control><Alt>e'),
-
-            # Till
-            ("TillMenu", None, _("_Till")),
-            ("TillOpen", None, _("Open Till..."), '<Control>F6'),
-            ("TillClose", None, _("Close Till..."), '<Control>F7'),
-
+             group.get('search_sold_items')),
+            ("Clients", None, _("Clients..."),
+             group.get('search_clients')),
+            ("ProductSearch", None, _("Products..."),
+             group.get('search_products')),
+            ("ServiceSearch", None, _("Services..."),
+             group.get('search_services')),
+            ("DeliverySearch", None, _("Deliveries..."),
+             group.get('search_deliveries')),
         ]
         self.pos_ui = self.add_ui_actions('', actions,
                                           filename='pos.xml')
-        self.set_help_section(_("POS help"), 'pdv-inicio')
+        self.set_help_section(_("POS help"), 'app-pos')
 
     def create_ui(self):
         self.sale_items.set_columns(self.get_columns())
@@ -183,7 +190,11 @@ class PosApp(AppWindow):
         self._setup_proxies()
         self._clear_order()
 
-    def activate(self):
+    def activate(self, params):
+        # Admin app doesn't have anything to print/export
+        for widget in (self.app.launcher.Print, self.app.launcher.ExportCSV):
+            widget.set_visible(False)
+
         # Hide toolbar specially for pos
         self.uimanager.get_widget('/toolbar').hide()
         self.uimanager.get_widget('/menubar/ViewMenu/ToggleToolbar').hide()
@@ -250,7 +261,7 @@ class PosApp(AppWindow):
 
     def _setup_printer(self):
         self._printer = FiscalPrinterHelper(self.conn,
-                                            parent=self.get_toplevel())
+                                            parent=self)
         self._printer.connect('till-status-changed',
                               self._on_PrinterHelper__till_status_changed)
         self._printer.connect('ecf-changed',
@@ -281,15 +292,15 @@ class PosApp(AppWindow):
             pop_fullscreen(window)
             window.unfullscreen()
 
-        for proxy in self.TillMenu.get_proxies():
-            proxy.props.visible = not self.param.POS_SEPARATE_CASHIER
+        for widget in (self.TillOpen, self.TillClose):
+            widget.set_visible(not self.param.POS_SEPARATE_CASHIER)
 
         if self.param.CONFIRM_SALES_ON_TILL:
             confirm_label = _("_Close")
         else:
             confirm_label = _("_Checkout")
         button_set_image_with_label(self.checkout_button,
-                                    'gtk-apply', confirm_label)
+                                    gtk.STOCK_APPLY, confirm_label)
 
     def _setup_widgets(self):
         self._inventory_widgets = [self.Sales, self.barcode, self.quantity,
@@ -508,6 +519,7 @@ class PosApp(AppWindow):
             double_click_confirm=True,
             info_message=message)
         if not sellable_view_item:
+            self.barcode.grab_focus()
             return
 
         sellable = Sellable.get(sellable_view_item.id, connection=self.conn)
@@ -795,6 +807,15 @@ class PosApp(AppWindow):
         assert self._coupon
         self._coupon.remove_item(sale_item)
 
+    def _close_till(self):
+        if self._sale_started:
+            if not yesno(_('You must finish or cancel the current sale before '
+                       'you can close the till.'),
+                     gtk.RESPONSE_NO, _("Cancel sale"), _("Finish sale")):
+                return
+            self._cancel_order(show_confirmation=False)
+        self._printer.close_till()
+
     #
     # Actions
     #
@@ -829,7 +850,7 @@ class PosApp(AppWindow):
         self._create_delivery()
 
     def on_TillClose__activate(self, action):
-        self._printer.close_till()
+        self._close_till()
 
     def on_TillOpen__activate(self, action):
         self._printer.open_till()
