@@ -36,11 +36,13 @@ from stoqlib.domain.production import ProductionOrder
 from stoqlib.gui.dialogs.productiondetails import ProductionDetailsDialog
 from stoqlib.gui.dialogs.productionquotedialog import ProductionQuoteDialog
 from stoqlib.gui.dialogs.startproduction import StartProductionDialog
+from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.search.productionsearch import (ProductionProductSearch,
                                                  ProductionItemsSearch,
                                                  ProductionHistorySearch)
 from stoqlib.gui.search.servicesearch import ServiceSearch
 from stoqlib.gui.wizards.productionwizard import ProductionWizard
+from stoqlib.gui.stockicons import STOQ_PRODUCTION_APP
 from stoqlib.reporting.production import ProductionReport
 
 from stoq.gui.application import SearchableAppWindow
@@ -51,10 +53,10 @@ _ = gettext.gettext
 class ProductionApp(SearchableAppWindow):
 
     app_name = _(u'Production')
-    app_icon_name = 'stoq-production-app'
     gladefile = "production"
     search_table = ProductionOrder
     search_label = _(u'matching:')
+    report_table = ProductionReport
     embedded = True
 
     #
@@ -62,52 +64,60 @@ class ProductionApp(SearchableAppWindow):
     #
 
     def create_actions(self):
+        group = get_accels('app.production')
         actions = [
             ('menubar', None, ''),
 
-            # Production
+            # File
             ('NewProduction', gtk.STOCK_NEW,
-             _('Production order...'), '<Control>o',
+             _('Production order...'),
+             group.get('new_production_order'),
              _('Create a new production')),
-            ('StartProduction', gtk.STOCK_CONVERT, _('Start production...'),
-             '<Control>t',
-             _('Start the selected production')),
-            ('EditProduction', gtk.STOCK_EDIT, _('Edit production...'), '',
-             _('Edit the selected production')
-            ),
-            ('ProductionDetails', gtk.STOCK_INFO, _('Production details...'),
-            '',
-            _('Show production details and register produced items')),
-            ('ProductionPurchaseQuote', 'stoq-purchase-app',
-             _('Purchase quote...'), '<Control>p'),
-            ('ExportCSV', gtk.STOCK_SAVE_AS, _('Export CSV...'), '<Control>F10'),
+            ('ProductionPurchaseQuote', STOQ_PRODUCTION_APP,
+             _('Purchase quote...'),
+             group.get('new_production_quote')),
 
-            ("Print", gtk.STOCK_PRINT, _("Print"), '',
-             _('Print a report of this production listing')),
+             # Production
+            ('ProductionMenu', None, _('Production')),
+            ('StartProduction', gtk.STOCK_CONVERT, _('Start production...'),
+             group.get('production_start'),
+             _('Start the selected production')),
+            ('EditProduction', gtk.STOCK_EDIT, _('Edit production...'),
+             group.get('production_edit'),
+             _('Edit the selected production')),
+            ('ProductionDetails', gtk.STOCK_INFO, _('Production details...'),
+             group.get('production_details'),
+            _('Show production details and register produced items')),
 
             # Search
-            ("SearchProduct", None, _("Production products..."), '<Control>d',
+            ("SearchProduct", None, _("Production products..."),
+             group.get('search_production_products'),
              _("Search for production products")),
-            ("SearchService", None, _("Services..."), '<Control>s',
+            ("SearchService", None, _("Services..."),
+             group.get('search_services'),
              _("Search for services")),
-            ("SearchProductionItem", 'stoq-production-app',
-             _("Production items..."), '<Control>r',
+            ("SearchProductionItem", STOQ_PRODUCTION_APP,
+             _("Production items..."),
+             group.get('search_production_items'),
              _("Search for production items")),
             ("SearchProductionHistory", None, _("Production history..."),
-             '<Control>h', _("Search for production history")),
-
+             group.get('search_production_history'),
+             _("Search for production history")),
         ]
         self.production_ui = self.add_ui_actions("", actions,
                                                  filename="production.xml")
-        self.set_help_section(_("Production help"), 'producao-inicio')
+        self.set_help_section(_("Production help"), 'app-production')
 
         self.NewProduction.set_short_label(_("New Production"))
         self.ProductionPurchaseQuote.set_short_label(_("Purchase"))
         self.SearchProductionItem.set_short_label(_("Search items"))
         self.StartProduction.set_short_label(_('Start'))
+        self.EditProduction.set_short_label(_('Edit'))
+        self.ProductionDetails.set_short_label(_('Details'))
         self.StartProduction.props.is_important = True
 
     def create_ui(self):
+        self.popup = self.uimanager.get_widget('/ProductionSelection')
         self.app.launcher.add_new_items([self.NewProduction,
                                          self.ProductionPurchaseQuote])
         self.app.launcher.add_search_items([
@@ -115,10 +125,10 @@ class ProductionApp(SearchableAppWindow):
             self.SearchService,
             self.SearchProductionItem,
             ])
+        self.app.launcher.Print.set_tooltip(
+            _("Print a report of these productions"))
 
-    def activate(self):
-        # Avoid letting this sensitive if has-rows is never emitted
-        self.Print.set_sensitive(False)
+    def activate(self, params):
         self.search.refresh()
         self._update_widgets()
 
@@ -151,6 +161,11 @@ class ProductionApp(SearchableAppWindow):
                 SearchColumn('close_date', title=_(u'Closed'),
                              data_type=datetime.date, width=80)]
 
+    def print_report(self, *args, **kwargs):
+        # ProductionReport needs a status kwarg
+        kwargs['status'] = self.status_filter.get_state().value
+        super(ProductionApp, self).print_report(*args, **kwargs)
+
     #
     # Private
     #
@@ -212,21 +227,18 @@ class ProductionApp(SearchableAppWindow):
     def on_ProductionDetails__activate(self, widget):
         self._production_details()
 
-    def on_Print__activate(self, widget):
-        items = self.results
-        self.print_report(ProductionReport, items, list(items),
-                          self.status_filter.get_state().value)
-
     def on_results__selection_changed(self, results, selected):
         self._update_widgets()
 
     def on_results__has_rows(self, widget, has_rows):
         self._update_widgets()
-        self.set_sensitive([self.Print], has_rows)
 
     def on_results__row_activated(self, widget, order):
         self._production_details()
 
+    def on_results__right_click(self, results, result, event):
+        self.popup.popup(None, None, None, event.button, event.time)
+
     # Production
 
     def on_NewProduction__activate(self, action):
