@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2005-2007 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2005-2012 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -33,7 +33,7 @@ from kiwi.datatypes import currency
 from kiwi.enums import SearchFilterPosition
 from kiwi.python import all
 from kiwi.ui.objectlist import Column, SearchColumn
-from kiwi.ui.search import ComboSearchFilter
+from kiwi.ui.search import ComboSearchFilter, DateSearchFilter
 from stoqlib.api import api
 from stoqlib.domain.payment.operation import register_payment_operations
 from stoqlib.domain.purchase import PurchaseOrder, PurchaseOrderView
@@ -41,6 +41,7 @@ from stoqlib.gui.dialogs.purchasedetails import PurchaseDetailsDialog
 from stoqlib.gui.dialogs.sellablepricedialog import SellablePriceDialog
 from stoqlib.gui.dialogs.stockcostdialog import StockCostDialog
 from stoqlib.gui.editors.producteditor import ProductEditor
+from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.search.categorysearch import (SellableCategorySearch,
                                                BaseSellableCatSearch)
 from stoqlib.gui.search.consignmentsearch import ConsignmentItemSearch
@@ -52,6 +53,7 @@ from stoqlib.gui.search.productsearch import (ProductSearch,
 from stoqlib.gui.search.purchasesearch import PurchasedItemsSearch
 from stoqlib.gui.search.sellableunitsearch import SellableUnitSearch
 from stoqlib.gui.search.servicesearch import ServiceSearch
+from stoqlib.gui.stockicons import (STOQ_PRODUCTS, STOQ_SUPPLIERS)
 from stoqlib.gui.wizards.consignmentwizard import (ConsignmentWizard,
                                                    CloseInConsignmentWizard)
 from stoqlib.gui.wizards.purchasefinishwizard import PurchaseFinishWizard
@@ -72,10 +74,10 @@ class PurchaseApp(SearchableAppWindow):
     # TODO: Change all widget.set_sensitive to self.set_sensitive([widget])
 
     app_name = _('Purchase')
-    app_icon_name = 'stoq-purchase-app'
     gladefile = "purchase"
     search_table = PurchaseOrderView
     search_label = _('matching:')
+    report_table = PurchaseReport
     embedded = True
 
     #
@@ -83,57 +85,73 @@ class PurchaseApp(SearchableAppWindow):
     #
 
     def create_actions(self):
+        group = get_accels('app.purchase')
         actions = [
-            ('menubar', None, ''),
-
-            # Purchase
-            ("Print", gtk.STOCK_PRINT, _("Print"), '',
-             _("Print the list of orders")),
-            ("StockCost", None, _("_Stock cost...")),
-            ('ExportCSV', gtk.STOCK_SAVE_AS, _('Export CSV...'), '<Control>F10'),
-            # Consignment
-            ("CloseInConsignment", None, _("Close consigment...")),
-            ("SearchInConsignmentItems", None, _("Search consigment items...")),
-
-            # Order
+            # File
             ("OrderMenu", None, _("Order")),
+            ("NewOrder", gtk.STOCK_NEW, _("Order..."),
+             group.get('new_order'),
+             _("Create a new purchase order")),
+            ("NewQuote", gtk.STOCK_INDEX, _("Quote..."),
+             group.get('new_quote'),
+             _("Create a new purchase quote")),
+            ("NewConsignment", None, _("Consignment..."),
+             group.get('new_consignment'),
+             _("Create a new purchase consignment")),
+            ("NewProduct", None, _("Product..."),
+             group.get('new_product'),
+             _("Create a new product")),
+            ("CloseInConsignment", None, _("Close consigment...")),
+
+            # Edit
+            ("StockCost", None, _("_Stock cost...")),
 
             # Search
-            ("BaseCategories", None, _("Base categories..."), "<Control>b"),
-            ("Categories", None, _("Categories..."), "<Control>c"),
-            ("Products", 'stoq-products', _("Products..."), "<Control>d"),
-            ("ProductUnits", None, _("Product units..."), "<Control>u"),
-            ("Services", None, _("Services..."), "<Control>s"),
-            ("SearchStockItems", None, _("Stock items..."), "<Control>i"),
+            ("BaseCategories", None, _("Base categories..."),
+             group.get("search_base_categories")),
+            ("Categories", None, _("Categories..."),
+             group.get("search_categories")),
+            ("Products", STOQ_PRODUCTS, _("Products..."),
+             group.get("search_products")),
+            ("ProductUnits", None, _("Product units..."),
+             group.get("search_product_units")),
+            ("Services", None, _("Services..."),
+             group.get("search_services")),
+            ("SearchStockItems", None, _("Stock items..."),
+             group.get("search_stock_items")),
             ("SearchClosedStockItems", None, _("Closed stock items..."),
-             "<Control><Alt>c"),
-            ("Suppliers", 'stoq-suppliers', _("Suppliers..."), "<Control>u"),
-            ("Transporter", None, _("Transporters..."), "<Control>t"),
-            ("SearchQuotes", None, _("Quotes..."), "<Control>e"),
-            ("SearchPurchasedItems", None, _("Purchased items..."), "<Control>p"),
-            ("ProductsSoldSearch", None, _("Products sold..."), ""),
-            ("ProductsPriceSearch", None, _("Prices editor..."), ""),
+             group.get("search_closed_stock_items")),
+            ("Suppliers", STOQ_SUPPLIERS, _("Suppliers..."),
+             group.get("search_suppliers")),
+            ("Transporter", None, _("Transporters..."),
+             group.get("search_transporters")),
+            ("SearchQuotes", None, _("Quotes..."),
+             group.get("search_quotes")),
+            ("SearchPurchasedItems", None, _("Purchased items..."),
+             group.get("search_purchased_items")),
+            ("ProductsSoldSearch", None, _("Sold products..."),
+             group.get("search_products_sold")),
+            ("ProductsPriceSearch", None, _("Prices..."),
+             group.get("search_prices")),
+            ("SearchInConsignmentItems", None, _("Search consigment items..."),
+             group.get("search_consignment_items")),
 
-            # Toolbar
-            ("NewOrder", gtk.STOCK_NEW, _("Order"), '<control>o',
-             _("Create a new purchase order")),
-            ("NewQuote", gtk.STOCK_INDEX, _("Quote"), '<control>e',
-             _("Create a new purchase quote")),
-            ("NewConsignment", None, _("Consignment"), '',
-             _("Create a new purchase consignment")),
-            ("NewProduct", None, _("Product"), '',
-             _("Create a new product")),
-
-            ("Confirm", gtk.STOCK_APPLY, _("Confirm"), '',
+            # Order
+            ("Confirm", gtk.STOCK_APPLY, _("Confirm..."),
+             group.get('order_confirm'),
              _("Confirm the selected order(s), marking it as sent to the "
                "supplier")),
-            ("Cancel", gtk.STOCK_CANCEL, _("Cancel"), '',
+            ("Cancel", gtk.STOCK_CANCEL, _("Cancel..."),
+             group.get('order_cancel'),
              _("Cancel the selected order")),
-            ("Edit", gtk.STOCK_EDIT, _("Edit"), '',
+            ("Edit", gtk.STOCK_EDIT, _("Edit..."),
+             group.get('order_edit'),
              _("Edit the selected order, allowing you to change it's details")),
-            ("Details", gtk.STOCK_INFO, _("Details"), '',
+            ("Details", gtk.STOCK_INFO, _("Details..."),
+             group.get('order_details'),
              _("Show details of the selected order")),
-            ("Finish", gtk.STOCK_APPLY, _("Finish"), '',
+            ("Finish", gtk.STOCK_APPLY, _("Finish..."),
+             group.get('order_finish'),
              _('Complete the selected partially received order')),
         ]
 
@@ -146,9 +164,13 @@ class PurchaseApp(SearchableAppWindow):
         self.NewQuote.set_short_label(_("New quote"))
         self.Products.set_short_label(_("Products"))
         self.Suppliers.set_short_label(_("Suppliers"))
+        self.Confirm.set_short_label(_("Confirm"))
+        self.Cancel.set_short_label(_("Cancel"))
+        self.Finish.set_short_label(_("Finish"))
+        self.Edit.set_short_label(_("Edit"))
+        self.Details.set_short_label(_("Details"))
 
-        self.set_help_section(_("Purchase help"),
-                              'compras-inicio')
+        self.set_help_section(_("Purchase help"), 'app-purchase')
         self.popup = self.uimanager.get_widget('/PurchaseSelection')
 
     def create_ui(self):
@@ -162,23 +184,22 @@ class PurchaseApp(SearchableAppWindow):
             self.Suppliers,
             self.SearchQuotes,
             self.Services])
-        parent = self.app.launcher.statusbar
         self.search.set_summary_label(column='total',
                                       label=_('<b>Orders total:</b>'),
                                       format='<b>%s</b>',
-                                      parent=parent)
-        self.search.search.search_button.hide()
+                                      parent=self.get_statusbar_message_area())
         self.results.set_selection_mode(gtk.SELECTION_MULTIPLE)
         self.Confirm.set_sensitive(False)
 
-    def activate(self):
-        # Avoid letting this sensitive if has-rows is never emitted
-        self.Print.set_sensitive(False)
+    def activate(self, params):
         self.app.launcher.NewToolItem.set_tooltip(
             _("Create a new purchase order"))
         self.app.launcher.SearchToolItem.set_tooltip(
             _("Search for purchase orders"))
-        self._update_view()
+        self.app.launcher.Print.set_tooltip(
+            _("Print a report of these orders"))
+        if not params.get('no-refresh'):
+            self._update_view()
         self.results.set_selection_mode(gtk.SELECTION_MULTIPLE)
 
     def setup_focus(self):
@@ -224,7 +245,7 @@ class PurchaseApp(SearchableAppWindow):
                 Column('status_str', title=_(u'Status'), data_type=str,
                        visible=False),
                 SearchColumn('open_date', title=_('Opened'),
-                              long_title='Date Opened', width=90,
+                              long_title=_('Date Opened'), width=90,
                               data_type=datetime.date, sorted=True,
                               order=gtk.SORT_DESCENDING),
                 SearchColumn('supplier_name', title=_('Supplier'),
@@ -239,6 +260,19 @@ class PurchaseApp(SearchableAppWindow):
                 SearchColumn('total', title=_('Total'),
                              data_type=currency, width=120)]
 
+    def print_report(self, *args, **kwargs):
+        # PurchaseReport needs a status arg
+        kwargs['status'] = self.status_filter.get_state().value
+        super(PurchaseApp, self).print_report(*args, **kwargs)
+
+    def search_for_date(self, date):
+        dfilter = DateSearchFilter(_("Expected receival date"))
+        dfilter.set_removable()
+        dfilter.mode.select_item_by_position(5)
+        self.add_filter(dfilter, columns=["expected_receival_date"])
+        dfilter.start_date.set_date(date)
+        self.search.refresh()
+
     #
     # Private
     #
@@ -247,7 +281,7 @@ class PurchaseApp(SearchableAppWindow):
         self._update_view()
 
     def _update_list_aware_widgets(self, has_items):
-        for widget in (self.Edit, self.Details, self.Print):
+        for widget in (self.Edit, self.Details):
             widget.set_sensitive(has_items)
 
     def _update_view(self):
@@ -351,11 +385,6 @@ class PurchaseApp(SearchableAppWindow):
         self.refresh()
         self.select_result(order_views)
 
-    def _print_selected_items(self):
-        items = self.results.get_selected_rows() or list(self.results)
-        self.print_report(PurchaseReport, self.results, items,
-                          self.status_filter.get_state().value)
-
     def _cancel_order(self):
         register_payment_operations()
         order_views = self.results.get_selected_rows()
@@ -407,13 +436,6 @@ class PurchaseApp(SearchableAppWindow):
     # Kiwi Callbacks
     #
 
-    def key_control_a(self, *args):
-        # FIXME Remove this method after gazpacho bug fix.
-        self._new_order()
-
-    def on_results__has_rows(self, klist, has_rows):
-        self.Print.set_sensitive(has_rows)
-
     def on_results__right_click(self, results, result, event):
         self.popup.popup(None, None, None, event.button, event.time)
 
@@ -439,9 +461,6 @@ class PurchaseApp(SearchableAppWindow):
     def on_Edit__activate(self, action):
         self._edit_order()
 
-    def on_Print__activate(self, action):
-        self._print_selected_items()
-
     def on_Cancel__activate(self, action):
         self._cancel_order()
 
@@ -470,6 +489,7 @@ class PurchaseApp(SearchableAppWindow):
 
     def on_SearchQuotes__activate(self, action):
         self.run_dialog(ReceiveQuoteWizard, self.conn)
+        self.refresh()
 
     def on_SearchPurchasedItems__activate(self, action):
         self.run_dialog(PurchasedItemsSearch, self.conn)
