@@ -51,10 +51,12 @@ from stoqlib.gui.dialogs.saledetails import SaleDetailsDialog
 from stoqlib.gui.dialogs.quotedialog import ConfirmSaleMissingDialog
 from stoqlib.gui.editors.tilleditor import CashInEditor, CashOutEditor
 from stoqlib.gui.fiscalprinter import FiscalPrinterHelper
+from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.search.personsearch import ClientSearch
 from stoqlib.gui.search.salesearch import SaleSearch, SoldItemsByBranchSearch
 from stoqlib.gui.search.tillsearch import TillFiscalOperationsSearch
 from stoqlib.gui.slaves.saleslave import return_sale
+from stoqlib.reporting.sale import SalesReport
 
 from stoq.gui.application import SearchableAppWindow
 
@@ -68,10 +70,10 @@ LOGO_HEIGHT = 32
 class TillApp(SearchableAppWindow):
 
     app_name = _(u'Till')
-    app_icon_name = 'stoq-till-app'
     gladefile = 'till'
     search_table = SaleView
     search_labels = _(u'matching:')
+    report_table = SalesReport
     embedded = True
 
     #
@@ -79,51 +81,57 @@ class TillApp(SearchableAppWindow):
     #
 
     def create_actions(self):
+        group = get_accels('app.till')
         actions = [
-            ('menubar', None, ''),
-
-            # Till
-            ("TillMenu", None, _("_Till")),
-            ('TillOpen', None, _('Open till...'), '<Control>F6'),
-            ('TillClose', None, _('Close till...'), '<Control>F7'),
-            ('ExportCSV', gtk.STOCK_SAVE_AS,
-             _('Export CSV...'), '<Control>F10'),
-
-            # New
+            ('SaleMenu', None, _('Sale')),
+            ('TillOpen', None, _('Open till...'),
+             group.get('open_till')),
+            ('TillClose', None, _('Close till...'),
+             group.get('close_till')),
             ('TillAddCash', None, _('Cash addition...'), ''),
             ('TillRemoveCash', None, _('Cash removal...'), ''),
-
-            # Search
-            ("SearchClient", None, _("Clients..."), '<Control><Alt>c',
+            ("SearchClient", None, _("Clients..."),
+             group.get('search_clients'),
              _("Search for clients")),
-            ("SearchSale", None, _("Sales..."), '<Contrl><Alt>a',
+            ("SearchSale", None, _("Sales..."),
+             group.get('search_sale'),
              _("Search for sales")),
             ("SearchSoldItemsByBranch", None, _("Sold items by branch..."),
-             '<Control><Alt>d', _("Search for items sold by branch")),
-            ("SearchTillHistory", None, _("Till history..."), '<Control><Alt>t',
+             group.get('search_sold_items_by_branch'),
+             _("Search for items sold by branch")),
+            ("SearchTillHistory", None, _("Till history..."),
+             group.get('search_till_history'),
              _("Search for till history")),
             ("SearchFiscalTillOperations", None, _("Fiscal till operations..."),
-             '<Contro><Alt>f', _("Search for fiscal till operations")),
-
-            ("Confirm", gtk.STOCK_APPLY, _("Confirm"), '',
+             group.get('search_fiscal_till_operations'),
+             _("Search for fiscal till operations")),
+            ("Confirm", gtk.STOCK_APPLY, _("Confirm..."),
+             group.get('confirm_sale'),
              _("Confirm the selected sale, decreasing stock and making it "
                "possible to receive it's payments")),
-            ("Return", gtk.STOCK_CANCEL, _("Return"), '',
+            ("Return", gtk.STOCK_CANCEL, _("Return..."),
+             group.get('return_sale'),
              _("Return the selected sale, returning stock and the client's "
                "payments")),
-            ("Details", gtk.STOCK_INFO, _("Details"), '',
+            ("Details", gtk.STOCK_INFO, _("Details..."),
+             group.get('sale_details'),
              _("Show details of the selected sale")),
         ]
 
         self.till_ui = self.add_ui_actions('', actions,
                                            filename="till.xml")
-        self.set_help_section(_("Till help"), 'caixa-inicio')
+        self.set_help_section(_("Till help"), 'app-till')
 
+        self.Confirm.set_short_label(_('Confirm'))
+        self.Return.set_short_label(_('Return'))
+        self.Details.set_short_label(_('Details'))
         self.Confirm.props.is_important = True
         self.Return.props.is_important = True
         self.Details.props.is_important = True
 
     def create_ui(self):
+        self.popup = self.uimanager.get_widget('/SaleSelection')
+
         self.current_branch = api.get_current_branch(self.conn)
         # Groups
         self.main_vbox.set_focus_chain([self.app_vbox])
@@ -138,12 +146,13 @@ class TillApp(SearchableAppWindow):
         return _('Stoq - Till for Branch %03d') % (
             api.get_current_branch(self.conn).id, )
 
-    def activate(self):
+    def activate(self, params):
         self.app.launcher.add_new_items([self.TillAddCash,
                                          self.TillRemoveCash])
         self.app.launcher.add_search_items([self.SearchFiscalTillOperations,
                                             self.SearchClient,
                                             self.SearchSale])
+        self.app.launcher.Print.set_tooltip(_("Print a report of these sales"))
         self.refresh()
         self._printer.check_till()
         self.check_open_inventory()
@@ -217,7 +226,7 @@ class TillApp(SearchableAppWindow):
 
     def _setup_printer(self):
         self._printer = FiscalPrinterHelper(self.conn,
-                                            parent=self.get_toplevel())
+                                            parent=self)
         self._printer.connect('till-status-changed',
                               self._on_PrinterHelper__till_status_changed)
         self._printer.connect('ecf-changed',
@@ -443,6 +452,9 @@ class TillApp(SearchableAppWindow):
     def on_results__has_rows(self, results, has_rows):
         self._update_total()
 
+    def on_results__right_click(self, results, result, event):
+        self.popup.popup(None, None, None, event.button, event.time)
+
     def on_Details__activate(self, action):
         self._run_details_dialog()
 
@@ -481,6 +493,7 @@ class TillApp(SearchableAppWindow):
             return
 
         self._run_search_dialog(SaleSearch)
+        self.refresh()
 
     def on_SearchSoldItemsByBranch__activate(self, button):
         self._run_search_dialog(SoldItemsByBranchSearch)
