@@ -35,12 +35,12 @@ import sys
 _ = gettext.gettext
 
 DATEUTIL_REQUIRED = (1, 4, 1)
-GTK_REQUIRED = (2, 16, 0)
+GTK_REQUIRED = (2, 17, 0)
 GUDEV_REQUIRED = (147, )
-KIWI_REQUIRED = (1, 9, 30)
+KIWI_REQUIRED = (1, 9, 32)
 MAKO_REQUIRED = (0, 2, 5)
 PIL_REQUIRED = (1, 1, 5)
-PYCAIRO_REQUIRED = (1, 8, 8)
+PYCAIRO_REQUIRED = (1, 8, 2)
 PYPOPPLER_REQUIRED = (0, 12, 1)
 PSQL_REQUIRED = (8, 4)
 PSYCOPG_REQUIRED = (2, 0, 5)
@@ -48,7 +48,7 @@ PYGTK_REQUIRED = (2, 16, 0)
 PYGTKWEBKIT_REQUIRED = (1, 1, 7)
 PYSERIAL_REQUIRED = (2, 1)
 REPORTLAB_REQUIRED = (2, 4)
-STOQDRIVERS_REQUIRED = (0, 9, 14)
+STOQDRIVERS_REQUIRED = (0, 9, 15)
 TWISTED_REQUIRED = (10, 0)
 ZOPE_INTERFACE_REQUIRED = (3, 0)
 
@@ -70,7 +70,7 @@ class DependencyChecker(object):
         self._check_pygtk(PYGTK_REQUIRED, GTK_REQUIRED)
         self._check_kiwi(KIWI_REQUIRED)
         self._check_pycairo(PYCAIRO_REQUIRED)
-        if platform.system() != 'Windows':
+        if platform.system() == 'Linux':
             self._check_pygtkwebkit(PYGTKWEBKIT_REQUIRED)
         self._check_zope_interface(ZOPE_INTERFACE_REQUIRED)
         self._check_dateutil(DATEUTIL_REQUIRED)
@@ -324,11 +324,12 @@ You can find an older version of %s on it's homepage at\n%s""") % (
                           url='http://labix.org/python-dateutil/',
                           version=version)
 
-        if map(int, dateutil.__version__.split('.')) < list(version):
+        if (not hasattr(dateutil, "__version__") or
+            map(int, dateutil.__version__.split('.')) < list(version)):
             self._too_old(project="Dateutil",
                           url='http://labix.org/python-dateutil/',
                           required=version,
-                          found=dateutil.__version__)
+                          found=getattr(dateutil, '__version__', 'unknown'))
 
     def _check_mako(self, version):
         try:
