@@ -132,7 +132,7 @@ def create_main_branch(trans, name):
     return branch
 
 
-def _register_payment_methods():
+def register_payment_methods(trans):
     """Registers the payment methods and creates persistent
     domain classes associated with them.
     """
@@ -140,13 +140,11 @@ def _register_payment_methods():
     from stoqlib.domain.payment.operation import register_payment_operations
 
     pom = PaymentOperationManager()
-    provide_utility(IPaymentOperationManager, pom)
+    provide_utility(IPaymentOperationManager, pom, replace=True)
 
     log.info("Registering payment operations")
     register_payment_operations()
 
-    trans = new_transaction()
-
     log.info("Creating domain objects for payment methods")
     account = sysparam(trans).IMBALANCE_ACCOUNT
     for operation_name in pom.get_operation_names():
@@ -162,8 +160,6 @@ def _register_payment_methods():
         pm.description = operation.description
         pm.max_installments = operation.max_installments
 
-    trans.commit(close=True)
-
 
 def register_accounts(trans):
     from stoqlib.domain.account import Account
@@ -344,11 +340,14 @@ def initialize_system():
     create_log("INIT START")
     trans = new_transaction()
     register_accounts(trans)
+    from stoqlib.domain.uiform import create_default_forms
+    create_default_forms(trans)
+    register_payment_methods(trans)
     trans.commit(close=True)
-    _register_payment_methods()
     ensure_sellable_constants()
     ensure_system_parameters()
     _ensure_card_providers()
     create_default_profiles()
     _install_invoice_templates()
+
     create_log("INIT DONE")
