@@ -44,7 +44,7 @@ log = Logger('stoqlib.database.tables')
 _tables = [
      ('system', ["SystemTable", "TransactionEntry"]),
      ('parameter', ["ParameterData"]),
-     ('account', ["BankAccount", "Bank"]),
+     ('account', ["BankAccount"]),
      ('profile', ["UserProfile", "ProfileSettings"]),
      ('person', ["Person"]),
      ('address', ["CityLocation", "Address"]),
@@ -62,7 +62,6 @@ _tables = [
                  "PersonAdaptToEmployee",
                  "PersonAdaptToBranch",
                  "PersonAdaptToSalesPerson",
-                 "PersonAdaptToBankBranch",
                  "PersonAdaptToCreditProvider",
                  "PersonAdaptToTransporter",
                  "EmployeeRoleHistory"]),
@@ -76,7 +75,6 @@ _tables = [
                           "PaymentAdaptToInPayment",
                           "PaymentAdaptToOutPayment"]),
      ('fiscal', ["CfopData", "FiscalBookEntry"]),
-     ('sellable', ["OnSaleInfo", "BaseSellableInfo"]),
      ('sale', ["SaleItem",
                "DeliveryItem",
                "SaleItemAdaptToDelivery",
