@@ -45,7 +45,7 @@ from stoqlib.domain.person import (Person, PersonAdaptToBranch,
                                    PersonAdaptToSupplier,
                                    PersonAdaptToTransporter,
                                    PersonAdaptToUser)
-from stoqlib.domain.sellable import Sellable, BaseSellableInfo, SellableUnit
+from stoqlib.domain.sellable import Sellable, SellableUnit
 from stoqlib.exceptions import DatabaseInconsistency, StoqlibError
 from stoqlib.lib.defaults import quantize
 from stoqlib.lib.translation import stoqlib_gettext
@@ -650,13 +650,12 @@ class PurchaseItemView(Viewable):
         total=PurchaseItem.q.cost * PurchaseItem.q.quantity,
         total_received=PurchaseItem.q.cost * PurchaseItem.q.quantity_received,
         total_sold=PurchaseItem.q.cost * PurchaseItem.q.quantity_sold,
-        description=BaseSellableInfo.q.description,
+        description=Sellable.q.description,
         unit=SellableUnit.q.description,
         )
 
     clause = AND(
         PurchaseOrder.q.id == PurchaseItem.q.orderID,
-        BaseSellableInfo.q.id == Sellable.q.base_sellable_infoID,
         )
 
     joins = [
@@ -799,3 +798,18 @@ class PurchaseOrderView(Viewable):
 
     def get_status_str(self):
         return PurchaseOrder.translate_status(self.status)
+
+    @classmethod
+    def select_confirmed(cls, due_date=None, connection=None):
+        query = cls.q.status == PurchaseOrder.ORDER_CONFIRMED
+
+        if due_date:
+            if isinstance(due_date, tuple):
+                date_query = AND(const.DATE(cls.q.expected_receival_date) >= due_date[0],
+                                 const.DATE(cls.q.expected_receival_date) <= due_date[1])
+            else:
+                date_query = const.DATE(cls.q.expected_receival_date) == due_date
+
+            query = AND(query, date_query)
+
+        return cls.select(query, connection=connection)
