@@ -42,17 +42,16 @@ from stoqlib.domain.base import Domain, ModelAdapter
 from stoqlib.domain.event import Event
 from stoqlib.domain.events import SaleStatusChangedEvent, ECFIsLastSaleEvent
 from stoqlib.domain.fiscal import FiscalBookEntry
-from stoqlib.domain.interfaces import (IContainer, IOutPayment,
+from stoqlib.domain.interfaces import (IContainer,
                                        IPaymentTransaction,
-                                       IDelivery, IStorable,
-                                       IInPayment)
+                                       IDelivery, IStorable)
 from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.person import (Person, PersonAdaptToClient,
                                    PersonAdaptToSalesPerson)
 from stoqlib.domain.product import Product, ProductHistory
 from stoqlib.domain.renegotiation import RenegotiationData
-from stoqlib.domain.sellable import Sellable, BaseSellableInfo
+from stoqlib.domain.sellable import Sellable
 from stoqlib.domain.service import Service
 from stoqlib.domain.taxes import SaleItemIcms, SaleItemIpi
 from stoqlib.domain.till import Till
@@ -175,7 +174,7 @@ class SaleItem(Domain):
         return self.get_quantity_delivered() == self.quantity
 
     def get_description(self):
-        return self.sellable.base_sellable_info.get_description()
+        return self.sellable.get_description()
 
     def is_service(self):
         service = Service.selectOneBy(sellable=self.sellable,
@@ -943,7 +942,7 @@ class SaleAdaptToPaymentTransaction(object):
             if self._already_have_commission(payment):
                 continue
             commission = self._create_commission(payment)
-            if IOutPayment(payment, None) is not None:
+            if payment.is_outpayment():
                 commission.value = -commission.value
 
     def cancel(self):
@@ -979,7 +978,7 @@ class SaleAdaptToPaymentTransaction(object):
         till = Till.get_current(self.sale.get_connection())
         for payment in payments:
             assert payment.is_pending(), payment.get_status_str()
-            assert IInPayment(payment, None)
+            assert payment.is_inpayment()
             till.add_entry(payment)
 
         # FIXME: Move this to a payment method specific hook
@@ -996,7 +995,7 @@ class SaleAdaptToPaymentTransaction(object):
 
         nitems = 0
         for item in self.sale.group.payments:
-            if IOutPayment(item, None) is None:
+            if not item.is_outpayment():
                 nitems += 1
 
         if nitems <= 1:
@@ -1298,14 +1297,12 @@ class DeliveryView(Viewable):
         estimated_fix_date=SaleItem.q.estimated_fix_date,
         completion_date=SaleItem.q.completion_date,
         address=SaleItemAdaptToDelivery.q.address,
-        description=BaseSellableInfo.q.description,
+        description=Sellable.q.description,
         client_name=Person.q.name,
     )
 
     joins = [LEFTJOINOn(None, Sellable,
                         SaleItem.q.sellableID == Sellable.q.id),
-             LEFTJOINOn(None, BaseSellableInfo,
-                        BaseSellableInfo.q.id == Sellable.q.base_sellable_infoID),
              LEFTJOINOn(None, DeliveryItem,
                         Sellable.q.id == DeliveryItem.q.sellableID),
              LEFTJOINOn(None, Sale, SaleItem.q.saleID == Sale.q.id),
@@ -1326,7 +1323,7 @@ class SoldSellableView(Viewable):
     columns = dict(
         id=Sellable.q.id,
         code=Sellable.q.code,
-        description=BaseSellableInfo.q.description,
+        description=Sellable.q.description,
 
         client_id=Sale.q.clientID,
         client_name=Person_Client.q.name,
@@ -1337,8 +1334,6 @@ class SoldSellableView(Viewable):
     joins = [
         LEFTJOINOn(None, SaleItem,
                     SaleItem.q.sellableID == Sellable.q.id),
-        LEFTJOINOn(None, BaseSellableInfo,
-                   BaseSellableInfo.q.id == Sellable.q.base_sellable_infoID),
         LEFTJOINOn(None, Sale,
                     Sale.q.id == SaleItem.q.saleID),
         LEFTJOINOn(None, PersonAdaptToClient,
