@@ -58,6 +58,7 @@ class _PluginModel(object):
 class PluginManagerDialog(BasicDialog):
     size = (500, 350)
     title = _(u'Plugin Manager')
+    help_section = 'plugin'
 
     def __init__(self, conn):
         BasicDialog.__init__(self)
@@ -77,7 +78,7 @@ class PluginManagerDialog(BasicDialog):
         self.ok_button.set_sensitive(selected.can_activate())
 
     def _setup_widgets(self):
-        self.set_ok_label(_(u'Activate'), 'gtk-apply')
+        self.set_ok_label(_(u'Activate'), gtk.STOCK_APPLY)
         self.ok_button.set_sensitive(False)
         plugins = []
 
