@@ -55,6 +55,9 @@ class ClientEditor(BasePersonRoleEditor):
     model_iface = IClient
     gladefile = 'BaseTemplate'
 
+    help_section = 'client'
+    ui_form_name = 'client'
+
     #
     # BaseEditor hooks
     #
@@ -80,6 +83,9 @@ class UserEditor(BasePersonRoleEditor):
     gladefile = 'BaseTemplate'
     USER_TAB_POSITION = 0
 
+    help_section = 'user'
+    ui_form_name = 'user'
+
     def __init__(self, conn, model=None, role_type=None, person=None,
                  visual_mode=False):
         BasePersonRoleEditor.__init__(self, conn, model, role_type, person,
@@ -161,6 +167,8 @@ class EmployeeEditor(BasePersonRoleEditor):
     model_iface = IEmployee
     gladefile = 'BaseTemplate'
 
+    ui_form_name = 'employee'
+
     #
     # BaseEditor hooks
     #
@@ -190,7 +198,15 @@ class EmployeeEditor(BasePersonRoleEditor):
         self.role_slave = EmployeeRoleSlave(self.conn, self.model,
                                             edit_mode=self.edit_mode,
                                             visual_mode=self.visual_mode)
+        db_form = self._person_slave.db_form
         slave._person_slave.attach_role_slave(self.role_slave)
+
+        if db_form:
+            db_form.update_widget(self.role_slave.role,
+                                  other=self.role_slave.role_lbl)
+            db_form.update_widget(self.role_slave.salary,
+                                  other=self.role_slave.salary_lbl)
+
         history_tab_label = _("Role History")
         history_slave = EmployeeRoleHistorySlave(self.model)
         slave._person_slave.attach_extra_slave(history_slave,
@@ -241,6 +257,9 @@ class SupplierEditor(BasePersonRoleEditor):
     model_iface = ISupplier
     gladefile = 'BaseTemplate'
 
+    help_section = 'supplier'
+    ui_form_name = 'supplier'
+
     #
     # BaseEditor hooks
     #
@@ -266,6 +285,9 @@ class TransporterEditor(BasePersonRoleEditor):
     model_iface = ITransporter
     gladefile = 'BaseTemplate'
 
+    help_section = 'transporter'
+    ui_form_name = 'transporter'
+
     #
     # BaseEditor hooks
     #
@@ -292,6 +314,9 @@ class BranchEditor(BasePersonRoleEditor):
     model_iface = IBranch
     gladefile = 'BaseTemplate'
 
+    help_section = 'branch'
+    ui_form_name = 'branch'
+
     #
     # BaseEditor hooks
     #
