@@ -34,12 +34,8 @@ from stoqlib.domain.person import Person
 from stoqlib.gui.base.wizards import (WizardEditorStep, BaseWizard,
                                       BaseWizardStep)
 from stoqlib.gui.base.dialogs import run_dialog
+from stoqlib.gui.editors.personeditor import BranchEditor, UserEditor
 from stoqlib.gui.templates.persontemplate import BasePersonRoleEditor
-from stoqlib.gui.editors.personeditor import (BranchEditor,
-                                              ClientEditor, SupplierEditor,
-                                              EmployeeEditor,
-                                              UserEditor,
-                                              CreditProviderEditor)
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.formatters import format_phone_number, raw_phone_number
 
@@ -188,6 +184,11 @@ class PersonRoleTypeStep(WizardEditorStep):
     def has_previous_step(self):
         return False
 
+    # Callbacks
+
+    def on_phone_number__activate(self, entry):
+        self.wizard.go_to_next()
+
 
 #
 # Main wizard
@@ -196,11 +197,6 @@ class PersonRoleTypeStep(WizardEditorStep):
 
 class PersonRoleWizard(BaseWizard):
 
-    ROLE_CLIENT = ClientEditor
-    ROLE_SUPPLIER = SupplierEditor
-    ROLE_CREDPROVIDER = CreditProviderEditor
-    ROLE_EMPLOYEE = EmployeeEditor
-
     size = (650, 450)
 
     def __init__(self, conn, role_editor):
@@ -213,6 +209,9 @@ class PersonRoleWizard(BaseWizard):
                             PersonRoleTypeStep(self, conn),
                             title=self.get_role_title())
 
+        if role_editor.help_section:
+            self.set_help_section(role_editor.help_section)
+
     def get_role_name(self):
         if not self.role_editor.model_name:
             raise ValueError('Editor %s must define a model_name attribute '
