@@ -35,7 +35,7 @@ from kiwi.python import Settable
 
 from stoqlib.api import api
 from stoqlib.database.orm import AND, OR
-from stoqlib.domain.interfaces import ISalesPerson
+from stoqlib.domain.interfaces import ISalesPerson, IStorable
 from stoqlib.domain.fiscal import CfopData
 from stoqlib.domain.payment.group import PaymentGroup
 from stoqlib.domain.payment.operation import register_payment_operations
@@ -254,7 +254,18 @@ class SaleQuoteItemStep(SellableItemStep):
             return item
 
     def get_saved_items(self):
-        return list(self.model.get_items())
+        items = self.model.get_items()
+        for i in items:
+            product = i.sellable.product
+            if not product:
+                continue
+            storable = IStorable(product, None)
+            if not storable:
+                continue
+            stock = storable.get_full_balance(self.model.branch)
+            i._stock_quantity = stock
+
+        return list(items)
 
     def get_columns(self):
         columns = [
@@ -335,7 +346,8 @@ class SaleQuoteItemStep(SellableItemStep):
         class MyList(SimpleListDialog):
             size = (500, 200)
 
-        run_dialog(MyList, self, columns, self.missing.values(), title="Missing products")
+        run_dialog(MyList, self, columns, self.missing.values(),
+                   title=_("Missing products"))
 
     def _validate_sellable_price(self, price):
         s = self.proxy.model.sellable
@@ -345,7 +357,7 @@ class SaleQuoteItemStep(SellableItemStep):
             if category:
                 info = s.get_category_price_info(category)
             if not info:
-                info = s.base_sellable_info
+                info = s
             return ValidationError(
                 _(u'Max discount for this product is %.2f%%') %
                 info.max_discount)
@@ -370,6 +382,7 @@ class SaleQuoteItemStep(SellableItemStep):
 
 class SaleQuoteWizard(BaseWizard):
     size = (775, 400)
+    help_section = 'sale-quote'
 
     def __init__(self, conn, model=None):
         title = self._get_title(model)
