@@ -321,7 +321,7 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         clients = self.client.get_model_items().values()
         if client in clients:
             if client.is_active:
-                self.client.update(client)
+                self.client.select(client)
             else:
                 # remove client from combo
                 self.client.select_item_by_data(client)
@@ -528,6 +528,7 @@ class ConfirmSaleWizard(BaseWizard):
     size = (600, 400)
     first_step = SalesPersonStep
     title = _("Sale Checkout")
+    help_section = 'sale-confirm'
 
     def __init__(self, conn, model):
         marker('ConfirmSaleWizard')
