@@ -28,6 +28,7 @@ from kiwi.log import Logger
 from stoqlib.database.interfaces import ICurrentBranch, ICurrentBranchStation
 from stoqlib.domain.station import BranchStation
 from stoqlib.database.runtime import new_transaction
+from stoqlib.importers.accountimporter import AccountImporter
 from stoqlib.importers.branchimporter import BranchImporter
 from stoqlib.importers.clientimporter import ClientImporter
 from stoqlib.importers.creditproviderimporter import CreditProviderImporter
@@ -76,3 +77,4 @@ def create(utilities=False):
     _import_one(PurchaseImporter, 'purchases.csv')
     _import_one(SaleImporter, 'sales.csv')
     _import_one(TransferImporter, 'transfers.csv')
+    _import_one(AccountImporter, 'accounts.csv')
